# Appendix to the Unlocked Literal Bible

## Origin and Purpose of the ULB

The Unlocked Literal Bible (ULB) is an open-licensed version of the Bible derived from The American Standard Version, and updated using the most reliable Hebrew, Aramaic, and Greek copies of the Biblical texts available. It is intended to accurately reflect the meanings of those texts and to be used as a source text for Bible translators to translate the Bible into their own language.

Some might call the ULB "relatively literal" because it retains many of the grammatical structures, idioms, figures of speech, and semantically complex vocabulary used in the Hebrew, Aramaic, and Greek source documents. But when those grammatical structures, idioms, or figures of speech would be unintelligible or seriously misunderstood in English, the ULB minimally adjusts the grammatical structures and wording in order to express the same meanings in ways that are more clear in English.

The ULB is not meant to be a refined, polished English version. It is meant to present the meaning and structure of the original texts in so far as that can be done clearly and simply, so that it can, in turn, be translated into other languages.

The ULB is intended to be used with other resources that help to clarify the meanings of words and phrases in the ULB or original languages. These resources also give suggestions about ways of expressing the meaning that translators might be able to use in their languages. These resources are Translation Words, Translation Notes, Translation Manual, Translation Questions, and the Unlocked Dynamic Bible (UDB).

  * **Translation Words** explain important terms that are repeated throughout the Bible.
  * **Translation Notes** explain complex theological terms and other translation issues. They also offer alternative translation suggestions.
  * **Translation Manual** explains different kinds of translation issues and provides strategies for dealing with them.
  * **Translation Questions** have questions and answers about the text. Translators can use these
      *  to test their own understanding of the ULB.
      *  to test their community's understanding of their translation to see if it is accurate and clear.
  * **The UDB** shows alternate ways of expressing the meaning in a more natural way. It also replaces many of the figures of speech in the ULB with plain language, and it makes some implicit information explicit.

## Notes About Making a "Relatively Literal" Translation
  * It is not possible to maintain a one-for-one correspondence between words in translation. One word from the source language may require a phrase for its translation in the target language, and vice-versa.
  * It is not possible to translate every word the same way every time it occurs and still have the correct meaning. So the ULB seeks to translate words with the meaning that they have in their context, using whatever English word or phrase is closest to that meaning.
  * Both Greek and Hebrew can make a sentence without using a verb, while English cannot. For the ULB to make sense, the verb will always be supplied. (Usually the verb is "is").
  * Greek makes abundant use of participial clauses. For the English of the ULB to make sense, often these must be changed to relative clauses or adverbial clauses.
  * In the ULB, the grammatical structures of the original languages are retained unless the English would be ungrammatical or easily misunderstood.

## Characteristics of the ULB
The ULB seeks to represent the language forms of the original in a way that also makes sense in English and other Gateway Languages.
  * The ULB tends to reflect the grammatical structures of the biblical languages.
  * The ULB tends to reflect the parts of speech of the biblical languages. For example, it seeks to use nouns where the original language uses nouns, adjectives where the original language uses adjectives, and so forth.
  * The ULB tends to reflect the semantically complex vocabulary of the original languages.
  * The ULB seeks to reproduce the form of the logical connections in the biblical languages. Thus, for example, the ULB has "the righteousness of faith" in Romans 4:13, and the logical relationship between righteousness and faith is not further specified. (Is it the righteousness that comes by faith? Is it the righteousness that vindicates faith?) All that "the righteousness of faith" explicitly signals is that there is some close association in the text between righteousness and faith, and that we can probably rule out a number of conceivable logical relationships between the two concepts, but not all possible relationships, as the foregoing example illustrates.
  * The ULB usually reproduces the linear succession of ideas found in the original, even when English may prefer a different arrangement of the same ideas.
  * The ULB does  not normally present information that is only implied in the original. For example, in Matthew 26:5, "For they were saying, 'Not during the festival, so that a riot does not arise among the people.'" The implied information is, "Let us not arrest Jesus [during the festival]." The ULB does not overtly represent this implied information.
  * The ULB reflects as much as reasonably possible the written style of the original. It has, for example, "Paul ... to Timothy..." instead of English's preferred, "Dear Timothy, this is Paul."
  * The ULB departs from closely representing the structures of the original only when it must do so for the sake of clarity in English.
  * Even when the ULB is ambiguous or not entirely clear (as is often true of the original), the ULB must never promote to the translator the wrong meaning.

## Decisions Concerning the ULB
The following are decisions that have been made concerning the ULB. This is not a comprehensive list, but it is here to help those who might wonder why the ULB is as it is.

### ULB Style
The following are details concerning the use of punctuation, capitalization, and vocabulary in the ULB.

  * Titles are capitalized. (Son of Man, King David, the Messiah).
  * All pronouns, even those referring to God, are lower case (except when beginning sentences and except for the first singular "I").
  * Quotation marks are used at the beginning and ending of direct speech. They are not used at the beginning of each verse, even though the speech may span several verses.
  * Punctuation is normally (not always) inside the quotation marks. 
  * Contractions are not used in the ULB.
  * Where possible, the ULB editors have used common vocabulary that is easy to translate into another language.
  * Numbers are written as words if they have only one or two words ("three hundred," "thirty-five thousand"). Otherwise they are written as numerals. ("205," "1,005")

### Footnotes in the ULB
The ULB has footnotes for the following kinds of issues: 
* names that have multiple spellings
* people and places that have multiple names
* differences in Hebrew and Greek copies that lead to differences in modern versions
* alternative renderings of verses that are very hard to understand in the original languages
* differences between copies of the texts in the original languages and the early Greek and Latin translations

The footnotes use the following words in refering to copies and translations:  
* "Copies" refers to extant copies of the Biblical text, written in the original language, or to copies of the Septuagint or Vulgate.
* "Text" or "original text" refers to the Hebrew or Greek or Aramaic text compiled from all sources (that is, from all extant copies).
* "Translation" refers to ancient translations (the Septuagint and the Vulgate) and to modern translations.
The ULB does not have footnotes for every textual issue, but it does address those that readers are most likely to encounter, particularly readers who have access to translations that were based on manuscripts known before the finding of the Dead Sea scrolls.

## Contributors to the ULB

{{manifest}}
